package com.example.myagenda

import android.content.ContentValues
import android.content.Context
import android.database.sqlite.SQLiteDatabase
import android.database.sqlite.SQLiteOpenHelper

class DBHelper(context: Context) : SQLiteOpenHelper(context, "agenda.db", null, 1){

    val sql = arrayOf(
        "CREATE TABLE contatos (id INTEGER PRIMARY KEY AUTOINCREMENT," +
                "nome TEXT, endereco TEXT, email TEXT, telefone INT)",
        "INSERT INTO contatos (nome, endereco, email, telefone) VALUES ('Paulo', 'rua do Paulo', 'paulo@gmail.com', 5555)",
        "INSERT INTO contatos (nome, endereco, email, telefone) VALUES ('Sandra', 'rua da Sandra', 'sandra@gmail.com', 4444)"
    )

    override fun onCreate(db: SQLiteDatabase) {
        sql.forEach {
            db.execSQL(it)
        }
    }

    override fun onUpgrade(p0: SQLiteDatabase?, p1: Int, p2: Int) {
        TODO("Not yet implemented")
    }

    fun listSelectAllContatos(): ArrayList<Contato> {
        val db = this.readableDatabase
        val cursor = db.rawQuery("SELECT * FROM contatos",null)
        val listaContatos : ArrayList<Contato> = ArrayList()
        if (cursor.count > 0) {
            cursor.moveToFirst()
            val idIndex = cursor.getColumnIndex("id")
            val nomeIndex = cursor.getColumnIndex("nome")
            val enderecoIndex = cursor.getColumnIndex("endereco")
            val emailIndex = cursor.getColumnIndex("email")
            val telefoneIndex = cursor.getColumnIndex("telefone")
            do {
                val id = cursor.getInt(idIndex)
                val nome = cursor.getString(nomeIndex)
                val endereco = cursor.getString(enderecoIndex)
                val email = cursor.getString(emailIndex)
                val telefone = cursor.getInt(telefoneIndex)

                val contato = Contato(id, nome, endereco, email, telefone)

                listaContatos.add(contato)
            } while (cursor.moveToNext())
        }
        db.close()
        return listaContatos
    }

    fun getContatosById(id: Int): Contato {
        val db = this.readableDatabase
        val cursor = db.rawQuery("SELECT * FROM contatos WHERE id=?", arrayOf(id.toString()))
        var contato = Contato()
        if (cursor.count == 1) {
            cursor.moveToFirst()
            val idIndex = cursor.getColumnIndex("id")
            val nomeIndex = cursor.getColumnIndex("nome")
            val enderecoIndex = cursor.getColumnIndex("endereco")
            val emailIndex = cursor.getColumnIndex("email")
            val telefoneIndex = cursor.getColumnIndex("telefone")

            val id = cursor.getInt(idIndex)
            val nome = cursor.getString(nomeIndex)
            val endereco = cursor.getString(enderecoIndex)
            val email = cursor.getString(emailIndex)
            val telefone = cursor.getInt(telefoneIndex)

            contato = Contato(id, nome, endereco, email, telefone)
        }
        db.close()
        return contato
    }

    fun inserirContato(
        nome: String,
        endereco: String,
        email: String,
        telefone: Int) : Long {
        val db = this.writableDatabase
        val contentValues = ContentValues()
        contentValues.put("nome", nome)
        contentValues.put("endereco", endereco)
        contentValues.put("email", email)
        contentValues.put("telefone", telefone)
        val res = db.insert("contatos", null, contentValues)
        db.close()
        return res
    }

    fun atualizarContato(
        id: Int,
        nome: String,
        endereco: String,
        email: String,
        telefone: Int) : Int {
        val db = this.writableDatabase
        val contentValues = ContentValues()
        contentValues.put("nome", nome)
        contentValues.put("endereco", endereco)
        contentValues.put("email", email)
        contentValues.put("telefone", telefone)
        val res = db.update("contatos", contentValues, "id=?", arrayOf(id.toString()))
        db.close()
        return res
    }

    fun deletarContato(id: Int) : Int {
        val db = this.writableDatabase
        val res = db.delete("contatos", "id=?", arrayOf(id.toString()))
        db.close()
        return res
    }

}